ASI Embedding Documentation — asiembedding 00.00.01 documentation

# ASI Embedding Documentation

ASI Embedding (placeholder name) is a Python wrapper for running QM-in-QM embedding simulations. The software package provides communincation protocols for matrix quantities between instances of different QM code system calls through the ASI (Atomic Simulation Interface) API. Inputs such as atomic structures and QM code keywords are comtrolled through integration with the Atomic Simulation Environment (ASE).

The software is currently under active development and is subject to major changes.

Contents:

- Installation
  - Requirements
  - ASI Embedding Installation
  - QM Driver Installation
- How It Works
  - Workflow
- QM Drivers
  - FHI-aims
- ASI Embedding Modules
  - ASI Embedding Package

# Indices and tables

- Index

- Search Page